#!/usr/bin/env python

"""
Command utility to examine a SEGY file

     Copyright (C) 2005  Kurt Schwehr

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

$Id: segystats.py,v 1.2 2005/10/13 20:22:11 schwehr Exp $

"""

# These values end up in the pydoc web page
__version__ = '$Revision: 1.2 $'.split()[1] # See man ident
__date__ = '$Date: 2005/10/13 20:22:11 $'.split()[1]
__author__ = 'Kurt Schwehr'

import os
import sys

from segy import Segy
import segy

from optparse import OptionParser
from segy_version import VERSION

myparser = OptionParser(usage="%prog [options] segyfile1 segyfile2 ... segyfileN",
                      version="%prog "+VERSION+' - '+__version__)

myparser.add_option('-d','--driver',dest="drv",
                    help="specify which driver to parse data file.  [default: %default]",
                    default="segy_drv_rev1")
myparser.add_option('-f','--file',dest="file",action="append", type="string",
                    help="specify segy file to examine.  Specify one or more of these")

from verbosity import BOMBASTIC,VERBOSE,TRACE,TERSE,ALWAYS
import verbosity
verbosity.addVerbosityOptions(myparser)

if __name__ == '__main__':
    (options,args) = myparser.parse_args()
    v = options.verbosity
    if v >= VERBOSE:   print '# Option values: ', options
    if v >= BOMBASTIC: print '# Arg    values: ', args

    for file in options.file:
        print
        print '# FILE: ',file
        s = Segy(file,drivername=options.drv,verbosity=options.verbosity)
        minSample =  10e99
        maxSample = -10e99
        for i in range(1,s.getNumberOfTraces()+1):
            data = s.getTraceData(i)
            minLocal = min(data)
            maxLocal = max(data)
            if (minLocal<minSample): minSample = minLocal
            if (maxLocal>maxSample): maxSample = maxLocal
            print i,minLocal,maxLocal,minSample,maxSample

# FIX: what else in terms of statistics would be good?
